@@ -64,6 +64,7 @@ categories = ['Orchestra Syntax:Header',
               'FLTK:Other',
               'FLTK:Appearance',
               'Mathematical Operations:Arithmetic and Logic Operations',
+              'Mathematical Operations:Arrays',
               'Mathematical Operations:Comparators and Accumulators',
               'Mathematical Operations:Mathematical Functions',
               'Mathematical Operations:Trigonometric Functions',
@@ -115,6 +116,12 @@ categories = ['Orchestra Syntax:Header',
               'Array Opcodes',
               'Array Operations: Fast Fourier Transform',
               'Array Operations: complex numbers',
+              'Array Operations: Discrete Cosine Transform',
+              'Array Operations: dot product',
+              'Array Operations: Mel scale filterbank',
+              'Array Operations: sorting',
+              'Array Operations: Cepstrum',
+              'Deprecated',
               'Miscellaneous',
               'Testing',
               'Utilities']
